Homewatcher
===========

Homewatcher is a free software that implements an alarm system built on top of Linknx.

Take advantage of your KNX motion or opening sensors to put your home under surveillance!

See the <a href="https://github.com/2franix/homewatcher/wiki">Wiki Pages</a> to learn more about how to install, configure and use Homewatcher.
